@@ -11,11 +11,13 @@
     <tags-item lemma="molt" tags="adv"/>
     <tags-item lemma="gaire" tags="adv"/>
     <tags-item lemma="no gaire" tags="adv"/>
+    <tags-item lemma="més" tags="adv"/>
   </def-label> 
   <def-label name="MOLTPREADV" closed="true">
     <tags-item lemma="molt" tags="preadv"/>
     <tags-item lemma="gaire" tags="preadv"/>
     <tags-item lemma="no gaire" tags="preadv"/>
+    <tags-item lemma="més" tags="preadv"/>
   </def-label>
  <def-label name="VOLERMOD" closed="true">
     <tags-item lemma="voler" tags="vbmod.*"/>
@@ -46,9 +48,12 @@
   <def-label name="CNJADV">
     <tags-item tags="cnjadv"/>
   </def-label>
-  <def-label name="DETQNT_ORD">
+  <def-label name="DETQNT">
     <tags-item tags="det.qnt.*"/>
+  </def-label> 
+  <def-label name="DETORD_ADJANT">
     <tags-item tags="det.ord.*"/>
+    <tags-item tags="adjant.*"/>
   </def-label> 
  <!-- <def-label name="DETNT" closed="true">
     <tags-item tags="detnt"/>
@@ -140,7 +145,7 @@
     <tags-item tags="prn.pro.*"/>
   </def-label>
   <def-label name="VA"><!--Afegit 10/11/05 MG -->
-    <tags-item lemma ="anar" tags="vblex.pri.*"/>
+    <tags-item lemma="anar" tags="vblex.pri.*"/>
   </def-label>
   <def-label name="VLEXINF">
     <tags-item tags="vblex.inf"/>
@@ -847,6 +852,10 @@
       <label-item label="DETM"/>
       <label-item label="VSERGER"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="DETM"/>
+      <label-item label="VSERPARTPI"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="DETM"/>
       <label-item label="VHABERPFCI"/>
@@ -935,6 +944,10 @@
       <label-item label="DETF"/>
       <label-item label="VSERGER"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="DETf"/>
+      <label-item label="VSERPARTPI"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="DETF"/>
       <label-item label="VHABERPFCI"/>
@@ -1023,6 +1036,10 @@
       <label-item label="DETMF"/>
       <label-item label="VSERGER"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="DETMF"/>
+      <label-item label="VSERPARTPI"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="DETMF"/>
       <label-item label="VHABERPFCI"/>
@@ -1709,8 +1726,221 @@
       <label-item label="QUEREL"/>
     </label-sequence>
 
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="PREP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VOLERMOD"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VOLERLEX"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VA"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VLEXINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VLEXGER"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VLEXPFCI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VLEXIPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VLEXSUBJ"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VLEXIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VSERINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VSERGER"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VSERPFCI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VSERIPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VSERSUBJ"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VSERIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VHABERINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VHABERGER"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VHABERPFCI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VHABERIPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VHABERSUBJ"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VMODALGER"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VMODALPFCI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VMODALIPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VMODALSUBJ"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence>
+ <!--   <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="DETQNT"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="DETM"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="DETF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PREADV"/>
+      <label-item label="DETMF"/>
+    </label-sequence> -->
 
-  
+
+    <label-sequence>
+      <label-item label="VLEXINF"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXGER"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXPARTPI"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXPFCI"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXIPI"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXSUBJ"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXIMP"/>
+      <label-item label="VMODALINF"/>
+    </label-sequence>
+
+
+    <label-sequence>
+      <label-item label="VLEXINF"/>
+      <label-item label="VMODALPARTPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXGER"/>
+      <label-item label="VMODALPARTPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXPARTPI"/>
+      <label-item label="VMODALPARTPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXPFCI"/>
+      <label-item label="VMODALPARTPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXIPI"/>
+      <label-item label="VMODALPARTPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXSUBJ"/>
+      <label-item label="VMODALPARTPI"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXIMP"/>
+      <label-item label="VMODALPARTPI"/>
+    </label-sequence>
+
+
+
+    <label-sequence>
+      <label-item label="VLEXINF"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXGER"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXPARTPI"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXPFCI"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXIPI"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXSUBJ"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VLEXIMP"/>
+      <label-item label="VMODALIMP"/>
+    </label-sequence> 
   </forbid>
 
   <enforce-rules>
@@ -1748,6 +1978,21 @@
 	<label-item label="PREADV"/>
       </label-set>
      </enforce-after> <!--Afegit 11/11/05 MG -->
+  <enforce-after label="PREADV">
+      <label-set>
+        <label-item label="ADV"/>
+        <label-item label="ADJM"/>
+        <label-item label="ADJF"/>
+	<label-item label="ADJMF"/>
+        <label-item label="VMODALPARTPI"/>
+        <label-item label="VLEXPARTPI"/>
+	<label-item label="VOLERMOD"/>
+	<label-item label="VOLERLEX"/>
+	<label-item label="MOLTPREADV"/>
+      </label-set>
+     </enforce-after>
+
+
   </enforce-rules>
 
   <preferences>
