@@ -6,7 +6,7 @@
     <tags-item lemma="to" tags="pr"/>
   </def-label> 
   <def-label name="FOR" closed="true">
-    <tags-item lemma="for" tags="pr"/><!--MG. afegit 19-09-06. confon <pr> amb <cnjadv>, tb en altres cases ('en'). Caldria fer algo al respecte o potser amb un text etiquetat ho fa millor. -->
+    <tags-item lemma="for" tags="cnjadv"/><!--MG. afegit 19-09-06. confon <pr> amb <cnjadv>, tb en altres cases ('en'). Caldria fer algo al respecte o potser amb un text etiquetat ho fa millor. -->
   </def-label> 
   <def-label name="THATCNJ" closed="true">
     <tags-item lemma="that" tags="cnjsub"/>
@@ -14,6 +14,9 @@
   <def-label name="NOT" closed="true">
     <tags-item lemma="not" tags="adv"/>
   </def-label>
+  <def-label name="NOADV" closed="true">
+    <tags-item lemma="no" tags="adv"/>
+  </def-label>
   <def-label name="CANNOM" closed="true">
     <tags-item lemma="can" tags="n.*"/>
   </def-label>
@@ -29,6 +32,15 @@
     <tags-item lemma="do" tags="vblex.pri.p3.sg"/>
     <tags-item lemma="do" tags="vblex.past"/>
   </def-label>
+
+<!--
+  <def-label name="VERBS_DISCURS_PP" closed="true">
+    <tags-item lemma="say" tags="vblex.pp"/>
+    <tags-item lemma="explain" tags="vblex.pp"/>
+    <tags-item lemma="add" tags="vblex.pp"/>
+    <tags-item lemma="tell" tags="vblex.pp"/>
+  </def-label>-->
+
   <def-label name="INTNOM" closed="true">
     <tags-item tags="prn.itg.*"/>
   </def-label> 
@@ -66,7 +78,7 @@
     <tags-item tags="det.ind.*"/>
     <tags-item tags="det.def.*"/>
     <tags-item tags="det.pos.*"/>
-    <tags-item tags="det.itg.*"/>
+    <tags-item tags="det.itg.*"/> 
   </def-label>
 <def-label name="DETQNT_ORD" closed="true"><!--Poden anar precedits dels altres tipus de determinant -->
     <tags-item tags="det.qnt.*"/>
@@ -84,6 +96,7 @@
   <def-label name="NOMSG">
     <tags-item tags="n.sg"/>
     <tags-item tags="n.acr.sg"/>
+    <tags-item tags="n.acr.sp"/>
     <tags-item tags="n.unc.sg"/>
   </def-label>
   <def-label name="NOMPL">
@@ -91,11 +104,13 @@
     <tags-item tags="n.acr.pl"/>
     <tags-item tags="n.unc.pl"/>
   </def-label>
+  
   <def-label name="INTERJ">
     <tags-item tags="ij"/>
   </def-label>
   <def-label name="ANTROPONIM">
     <tags-item tags="np.ant.*"/>
+    <tags-item tags="np.cog.*"/>
   </def-label>
   <def-label name="TOPONIM">
     <tags-item tags="np.loc.*"/>
@@ -224,6 +239,9 @@
   <def-label name="RELAN" closed="true">
     <tags-item tags="rel.an.*"/>
   </def-label>
+  <def-label name="RELAA" closed="true">
+    <tags-item tags="rel.aa.*"/>
+  </def-label>
   <def-label name="RELNN" closed="true">
     <tags-item tags="rel.nn.*"/>
   </def-label>
@@ -257,6 +275,14 @@
       <label-item label="PRNALTRES"/>
       <label-item label="NOMPL"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="PRNALTRES"/>
+      <label-item label="CANNOM"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PRNALTRES"/>
+      <label-item label="WILLNOM"/>
+    </label-sequence>
    <label-sequence>
       <label-item label="VHAVEPP"/>
       <label-item label="PAST"/>
@@ -301,7 +327,11 @@
     <label-sequence>
       <label-item label="PRNSUBJ"/>
       <label-item label="VLEXPP"/>
-    </label-sequence>
+    </label-sequence> 
+  <!--  <label-sequence>
+      <label-item label="PRNSUBJ"/>
+      <label-item label="VERBS_DISCURS_PP"/>
+    </label-sequence> -->
     <label-sequence>
       <label-item label="PRNSUBJ"/>
       <label-item label="VSERPP"/>
@@ -327,6 +357,30 @@
       <label-item label="PRNSUBJ"/>
       <label-item label="NOMPL"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="PRNSUBJ"/>
+      <label-item label="CANNOM"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PRNSUBJ"/>
+      <label-item label="WILLNOM"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PRNSUBJ"/>
+      <label-item label="DET"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PRNSUBJ"/>
+      <label-item label="DETQNT_ORD"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PRNSUBJ"/>
+      <label-item label="PREDET"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PRNSUBJ"/>
+      <label-item label="NUM"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="PRNSUBJ"/>
       <label-item label="VMODINF"/>
@@ -375,6 +429,50 @@
       <label-item label="RELADV"/>
       <label-item label="PRES"/>      
     </label-sequence>
+
+    <label-sequence>
+      <label-item label="RELAN"/>
+      <label-item label="VLEXPP"/>     
+    </label-sequence>
+    <label-sequence>
+      <label-item label="RELAN"/>
+      <label-item label="VSERPP"/>      
+    </label-sequence>
+    <label-sequence>
+      <label-item label="RELAN"/>
+      <label-item label="VMODPP"/>      
+    </label-sequence>
+    <label-sequence>
+      <label-item label="RELAN"/>
+      <label-item label="VHAVEPP"/>      
+    </label-sequence>
+  <!--  <label-sequence>
+      <label-item label="RELAN"/>
+      <label-item label="VERBS_DISCURS_PP"/>      
+    </label-sequence> -->
+    <label-sequence><!--no estic segura que aquesta prohib sigui adequada per a tots els rel 'nn' -->
+      <label-item label="RELNN"/>
+      <label-item label="VLEXPP"/>    
+    </label-sequence>
+    <label-sequence>
+      <label-item label="RELNN"/>
+      <label-item label="VSERPP"/>      
+    </label-sequence>
+    <label-sequence>
+      <label-item label="RELNN"/>
+      <label-item label="VMODPP"/>      
+    </label-sequence>
+    <label-sequence>
+      <label-item label="RELNN"/>
+      <label-item label="VHAVEPP"/>      
+    </label-sequence>
+ <!--   <label-sequence>
+      <label-item label="RELNN"/>
+      <label-item label="VERBS_DISCURS_PP"/>      
+    </label-sequence> -->
+
+ 
+
     <label-sequence><!--'Visitors who wanted to come', pq esculli el rel (no obstant, es farà malament: ask visitors who is the first) -->
       <label-item label="NOMSG"/>
       <label-item label="INTNOM"/>      
@@ -396,7 +494,11 @@
     <label-sequence>
       <label-item label="ANTROPONIM"/>
       <label-item label="VLEXPP"/>
-    </label-sequence> 
+    </label-sequence>
+  <!--  <label-sequence>
+      <label-item label="ANTROPONIM"/>
+      <label-item label="VERBS_DISCURS_PP"/>
+    </label-sequence> -->
     <label-sequence>
       <label-item label="ANTROPONIM"/>
       <label-item label="VSERPP"/>
@@ -409,6 +511,10 @@
       <label-item label="TOPONIM"/>
       <label-item label="VLEXPP"/>
     </label-sequence> 
+ <!--   <label-sequence>
+      <label-item label="TOPONIM"/>
+      <label-item label="VERBS_DISCURS_PP"/>
+    </label-sequence>  -->
     <label-sequence>
       <label-item label="TOPONIM"/>
       <label-item label="VSERPP"/>
@@ -420,7 +526,11 @@
     <label-sequence>
       <label-item label="NPALTRES"/>
       <label-item label="VLEXPP"/>
-    </label-sequence> 
+    </label-sequence>
+  <!--  <label-sequence>
+      <label-item label="NPALTRES"/>
+      <label-item label="VERBS_DISCURS_PP"/>
+    </label-sequence> -->
     <label-sequence>
       <label-item label="NPALTRES"/>
       <label-item label="VSERPP"/>
@@ -433,6 +543,14 @@
       <label-item label="DOVBLEX"/>
       <label-item label="PRNSUBJ"/>
     </label-sequence> 
+    <label-sequence>
+      <label-item label="DOVBLEX"/>
+      <label-item label="PRNOBJ"/>
+    </label-sequence> 
+    <label-sequence>
+      <label-item label="VDO"/>
+      <label-item label="PRNOBJ"/>
+    </label-sequence> 
     <label-sequence>
       <label-item label="DOVBLEX"/>
       <label-item label="NOT"/>
@@ -445,6 +563,18 @@
       <label-item label="ADJPOS"/>
       <label-item label="NOMPL"/>
     </label-sequence>
+    <label-sequence>
+      <label-item label="ADJPOS"/>
+      <label-item label="CANNOM"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="ADJPOS"/>
+      <label-item label="WILLNOM"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="PRNSUBJ"/>
+      <label-item label="CANNOM"/>
+    </label-sequence>
     <label-sequence>
       <label-item label="CANNOM"/>
       <label-item label="PRNSUBJ"/>
@@ -634,9 +764,72 @@
       <label-item label="DET"/>
       <label-item label="VAUX"/>
     </label-sequence>
-    <label-sequence><!--MG: soluciona "popular will." però no: yes, they will. Pensar-hi millor. -->
+  <!--  <label-sequence><!-x-MG: soluciona "popular will." però no: yes, they will. Pensar-hi millor. -x->
       <label-item label="VAUX"/>
       <label-item label="SENT"/>
+    </label-sequence> -->
+
+
+    <label-sequence>
+      <label-item label="NOADV"/>
+      <label-item label="PAST"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NOADV"/>
+      <label-item label="INF"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NOADV"/>
+      <label-item label="PRES"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NOADV"/>
+      <label-item label="GER"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NOADV"/>
+      <label-item label="NOMSG"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NOADV"/>
+      <label-item label="NOMPL"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NOADV"/>
+      <label-item label="CANNOM"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="NOADV"/>
+      <label-item label="WILLNOM"/>
+    </label-sequence>
+
+  <!--  <label-sequence>
+      <label-item label="VERBS_DISCURS"/>
+      <label-item label="NOMPL"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VERBS_DISCURS"/>
+      <label-item label="NOMSG"/>
+    </label-sequence> -->
+   <!-- <label-sequence>
+      <label-item label="CM"/>
+      <label-item label="VERBS_DISCURS_PP"/>
+    </label-sequence> -->
+   <!-- <label-sequence>
+      <label-item label="VERBS_DISCURS"/>
+      <label-item label="DET"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="VERBS_DISCURS"/>
+      <label-item label="DETQNT_ORD"/>
+    </label-sequence>-->
+    <label-sequence>
+      <label-item label="PRNSUBJ"/>
+      <label-item label="GEN"/>
+    </label-sequence>
+    <label-sequence>
+      <label-item label="INTNOM"/>
+      <label-item label="DETQNT_ORD"/>
     </label-sequence>
 
 
@@ -647,6 +840,7 @@
     <enforce-after label="VHAVEPAST">
       <label-set>
         <label-item label="VLEXPP"/>
+       <!-- <label-item label="VERBS_DISCURS_PP"/>-->
         <label-item label="VSERPP"/>
 	<label-item label="ADV"/>
 	<label-item label="NOT"/>
@@ -656,6 +850,7 @@
     <enforce-after label="VHAVEINF">
       <label-set>
         <label-item label="VLEXPP"/>
+      <!--  <label-item label="VERBS_DISCURS_PP"/>-->
         <label-item label="VSERPP"/>
 	<label-item label="ADV"/>
       </label-set>
@@ -663,6 +858,7 @@
      <enforce-after label="VHAVEPRES">
       <label-set>
         <label-item label="VLEXPP"/>
+    <!--    <label-item label="VERBS_DISCURS_PP"/>-->
         <label-item label="VSERPP"/>
 	<label-item label="ADV"/>
 	<label-item label="NOT"/>
@@ -672,6 +868,7 @@
      <enforce-after label="VHAVE">
       <label-set>
         <label-item label="VLEXPP"/>
+       <!-- <label-item label="VERBS_DISCURS_PP"/>-->
         <label-item label="VSERPP"/>
 	<label-item label="ADV"/>
 	<label-item label="NOT"/>
@@ -682,11 +879,39 @@
       <label-set>
         <label-item label="NOMSG"/>
         <label-item label="NOMPL"/>
+        <label-item label="CANNOM"/>
+        <label-item label="WILLNOM"/>
 	<label-item label="ADJ"/>
 	<label-item label="DET"/>
       </label-set>
     </enforce-after>
 
+     <enforce-after label="GEN">
+      <label-set>
+        <label-item label="NOMSG"/>
+        <label-item label="NOMPL"/>
+        <label-item label="CANNOM"/>
+        <label-item label="WILLNOM"/>
+	<label-item label="ADJ"/>
+	<label-item label="DETQNT_ORD"/>
+	<label-item label="NUM"/>
+	<label-item label="ANTROPONIM"/>
+	<label-item label="TOPONIM"/>
+	<label-item label="NPALTRES"/>
+      </label-set>
+    </enforce-after>
+     <enforce-after label="RELAA">
+      <label-set>
+        <label-item label="NOMSG"/>
+        <label-item label="NOMPL"/>
+        <label-item label="CANNOM"/>
+        <label-item label="WILLNOM"/>
+	<label-item label="ADJ"/>
+	<label-item label="DET"/>
+	<label-item label="DETQNT_ORD"/>
+      </label-set>
+    </enforce-after>
+
 <!--   <enforce-after label="VAUX"><!-*-afegit MG 26/02/07 -*->
       <label-set>
         <label-item label="PRNSUBJ"/>
@@ -776,12 +1001,14 @@
 	<label-item label="CM"/>
       </label-set>
     </enforce-after> -->
-
-
- 
-   
+  
 
  </enforce-rules>
 
 
+ <preferences>
+   <prefer tags="n.acr.sg"/>
+ </preferences>
+
+
 </tagger>
